==> haskell-emojis-0.1.3-12-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-emojis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 emojis
version:              0.1.3
visibility:           public
id:                   emojis-0.1.3-7lp6bSa8ElkLZwS3L5NWjG
key:                  emojis-0.1.3-7lp6bSa8ElkLZwS3L5NWjG
license:              BSD-3-Clause
copyright:            2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/emojis#readme
synopsis:             Conversion between emoji characters and their names.
description:
    This package provides functions for converting
    emoji names to emoji characters and vice versa.

    How does it differ from the @emoji@ package?

    -   It supports a fuller range of emojis, including all those
    supported by GitHub
    -   It supports lookup of emoji aliases from emoji
    -   It uses Text rather than String
    -   It has a lighter dependency footprint: in particular, it
    does not require aeson
    -   It does not require TemplateHaskell

category:             Text
abi:                  0a0fc48bdbccd575b0328de06e137bed
exposed:              True
exposed-modules:      Text.Emoji
import-dirs:          /usr/lib/ghc-9.2.8/site-local/emojis-0.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/emojis-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-emojis
hs-libraries:         HSemojis-0.1.3-7lp6bSa8ElkLZwS3L5NWjG
depends:              base-4.16.4.0 containers-0.6.5.1 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-emojis/html/emojis.haddock
haddock-html:         /usr/share/doc/haskell-emojis/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-emojis-0.1.4.1-12.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-emojis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 emojis
version:              0.1.4.1
visibility:           public
id:                   emojis-0.1.4.1-FZxZVzFxHM1FXNM5saKrpG
key:                  emojis-0.1.4.1-FZxZVzFxHM1FXNM5saKrpG
license:              BSD-3-Clause
copyright:            2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/emojis#readme
synopsis:             Conversion between emoji characters and their names.
description:
    This package provides functions for converting
    emoji names to emoji characters and vice versa.

    How does it differ from the @emoji@ package?

    -   It supports a fuller range of emojis, including all those
    supported by GitHub
    -   It supports lookup of emoji aliases from emoji
    -   It uses Text rather than String
    -   It has a lighter dependency footprint: in particular, it
    does not require aeson
    -   It does not require TemplateHaskell

category:             Text
abi:                  b57d47d01c075a31cf20c21c81878c5b
exposed:              True
exposed-modules:      Text.Emoji
hidden-modules:       Trie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/emojis-0.1.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/emojis-0.1.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/emojis-0.1.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-emojis
hs-libraries:         HSemojis-0.1.4.1-FZxZVzFxHM1FXNM5saKrpG
depends:              base-4.17.2.1 containers-0.6.7 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-emojis/html/emojis.haddock
haddock-html:         /usr/share/doc/haskell-emojis/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
